# 2-examples.r

# the example code included in the paper and appendix

## Section 4, Figure 4

# Not shown: 
example_data <- structure(list(month = structure(1:12, 
  .Label = c("Jan", "Feb", "March", "April", "May", "June", "July", 
             "Aug", "Sept", "Oct", "Nov", "Dec"), class = "factor"),
  co2 = c(-0.06, 0.6, 1.31, 2.42, 2.92, 2.3, 0.84, -1.19, -2.97, 
          -3.21, -2.03, -0.95), 
  season = c("Winter", "Winter", "Spring", "Spring", "Spring", 
             "Summer", "Summer", "Summer", "Fall", "Fall", "Fall", 
             "Winter")), 
  .Names = c("month", "co2", "season"), 
  row.names = c(NA, -12L), class = "data.frame")

# Shown: 
library(ggplot2)
ggplot(example_data) +
  geom_point(mapping = aes(x = month, y = co2))


## Section 4, Figure 5

ggplot(example_data) +
  geom_point(mapping = aes(x = month, y = co2, shape = season))


## Section 4, Figure 7

library(ggsubplot)
ggplot(carbon) +
  geom_subplot(aes(x = month,
   y = mean(seasonal, na.rm = TRUE),
   group = month,
   subplot = geom_line(aes(x = year,
     y = seasonal - mean(seasonal)))))


## Section 4, Figure 9

ggplot(nasa) +
  geom_point(aes(x = surftemp, y = temperature))

ggplot(nasa) +
  map_americas +
  geom_subplot(aes(x = long, 
    y = lat,
    group = id,
    subplot = geom_point(aes(x = surftemp,
      y = temperature))))

ggplot(nasa) +
  map_americas +
  geom_subplot(aes(x = long,
    y = lat,
    group = id,
    subplot = geom_star(aes(r = fahrenheit, 
      angle = date,
      fill = mean(fahrenheit)),
      r.zero = FALSE)))

ggplot(nasa) +
  geom_subplot(aes(x = max(surftemp),
    y = min(surftemp),
    group = id,
    subplot = geom_star(aes(r = surftemp,
      angle = date,
      fill = mean(fahrenheit)),
      r.zero = FALSE)))


##### Appendix


## Section A.1, Figure 1

library(ggplot2)
library(ggsubplot)
one_nasa <- nasa[nasa$id == "1-1", ]

# Figure A1.a, a star geom
ggplot(one_nasa) +
  geom_line(aes(x = date, y = fahrenheit)) +
  coord_polar()

# Figure A1.b, a star geom
ggplot(one_nasa) +
  geom_freqpoly(aes(x = ozone)) +
  coord_polar()

# Figure A1.c, a coxcomb geom
ggplot(diamonds) +
  geom_bar(aes(x = color, fill = color)) +
  coord_polar()

# Figure A1.d, star geom
ggplot(one_nasa) +
  geom_star(aes(angle = date, r = fahrenheit,
    fill = mean(fahrenheit)), r.zero = FALSE)

# Figure A1.e, freqstar geom
ggplot(one_nasa) +
  geom_freqstar(aes(angle = ozone, fill = mean(ozone)))

# Figure A1.f, coxcomb geom
ggplot(diamonds) +
  geom_coxcomb(aes(angle = color, fill = color))


## Section A2, Figure 3

# Figure A3.a overplotted ozone vs. temperature￼
ggplot(nasa) +
  geom_point(aes(x = atmos.fahrenheit, y = ozone, color = lat))

# Figure A3.b. Combine like points, plot their means
ggplot(nasa) +
  ply_aes(geom_point(aes(x = mean(atmos.fahrenheit), 
    y = mean(ozone), color = lat[1], 
    group = interaction(long, lat))))


## Section A3, Figure 4

# Default width and height
ggplot(nasa) +
  geom_subplot(aes(long, lat, group = id,
    subplot = geom_star(aes(r = fahrenheit, angle = date,
      fill = mean(fahrenheit)), r.zero = FALSE)))

# Decreased width and height
ggplot(nasa) +
  geom_subplot(aes(long, lat, group = id,
    subplot = geom_star(aes(r = fahrenheit, angle = date,
      fill = mean(fahrenheit)), r.zero = FALSE)),
    width = 1, height = 1)

# Relative widths and heights
ggplot(nasa) + 
  geom_subplot(aes(long, lat, group = id, 
    subplot = geom_star(aes(r = fahrenheit, angle = date, 
      fill = mean(fahrenheit)), r.zero = FALSE)),
    width = rel(1.5), height = rel(1.5))
                   

## Section A4, Figure 5

ggplot(seasons) + 
  geom_subplot(aes(lon, lat, group = stn, 
    subplot = geom_line(aes(x = time, y = pred))), 
    height = 1, width = 2, position = "merge")

ggplot(seasons) + 
  geom_subplot2d(aes(lon, lat, 
    subplot = geom_line(aes(x = time, y = pred))), 
    binwidth = c(2, 1))

